Fourier-Based Metrics (PUFMeter)
--------------------------------

An advanced method to study Boolean functions is harmonic analysis, also known as Fourier analysis [ODon14]_.
It can give information about the properties, including learnability, of a given Boolean function.
pypuf formalizes (noise-free) PUFs as Boolean functions and can compute some of the metrics used in PUFMeter [GFS19]_.


.. automodule:: pypuf.metrics
    :members: influence, total_influence, noise_sensitivity
    :noindex:
